Module text

Module text 

Modules

font
format
pos
wrapping

Structs

Text

Enums

PixelFont
PixelFont is used to set the size and positioning in pixels of text

Constants

ASCII_CENT
ASCII_CHECK
ASCII_CURRENCY
ASCII_DEGREE
ASCII_ELLIPSIS
ASCII_EURO
ASCII_POUND
ASCII_YEN
SUPPORTED_SYMBOLS

Functions

chr_to_code
measure_text
Return size in pixels for text Run text through wrapping strategy first